@@ -24,7 +24,12 @@ use crate::{
     channel::{embed::Embed, Attachment, Channel, ChannelMention},
     datetime::Timestamp,
     guild::PartialMember,
-    id::{ApplicationId, ChannelId, GuildId, MessageId, RoleId, WebhookId},
+    id::{
+        marker::{
+            ApplicationMarker, ChannelMarker, GuildMarker, MessageMarker, RoleMarker, WebhookMarker,
+        },
+        Id,
+    },
     user::User,
 };
 use serde::{Deserialize, Serialize};
@@ -39,10 +44,10 @@ pub struct Message {
     ///
     /// Sent if the message is a response to an Interaction.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub application_id: Option<ApplicationId>,
+    pub application_id: Option<Id<ApplicationMarker>>,
     pub attachments: Vec<Attachment>,
     pub author: User,
-    pub channel_id: ChannelId,
+    pub channel_id: Id<ChannelMarker>,
     /// List of provided message components.
     #[serde(default, skip_serializing_if = "Vec::is_empty")]
     pub components: Vec<Component>,
@@ -52,8 +57,8 @@ pub struct Message {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub flags: Option<MessageFlags>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub guild_id: Option<GuildId>,
-    pub id: MessageId,
+    pub guild_id: Option<Id<GuildMarker>>,
+    pub id: Id<MessageMarker>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub interaction: Option<MessageInteraction>,
     #[serde(rename = "type")]
@@ -63,7 +68,7 @@ pub struct Message {
     #[serde(default, skip_serializing_if = "Vec::is_empty")]
     pub mention_channels: Vec<ChannelMention>,
     pub mention_everyone: bool,
-    pub mention_roles: Vec<RoleId>,
+    pub mention_roles: Vec<Id<RoleMarker>>,
     pub mentions: Vec<Mention>,
     pub pinned: bool,
     #[serde(default, skip_serializing_if = "Vec::is_empty")]
@@ -85,21 +90,22 @@ pub struct Message {
     pub thread: Option<Channel>,
     pub tts: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub webhook_id: Option<WebhookId>,
+    pub webhook_id: Option<Id<WebhookMarker>>,
 }
 
 #[cfg(test)]
 mod tests {
     use super::{
-        sticker::{MessageSticker, StickerFormatType, StickerId},
+        sticker::{MessageSticker, StickerFormatType},
         ChannelMention, Message, MessageActivity, MessageActivityType, MessageApplication,
-        MessageFlags, MessageReaction, MessageReference, MessageType, WebhookId,
+        MessageFlags, MessageReaction, MessageReference, MessageType,
     };
     use crate::{
         channel::{ChannelType, ReactionType},
         datetime::{Timestamp, TimestampParseError},
         guild::PartialMember,
-        id::{ApplicationId, ChannelId, GuildId, MessageId, UserId},
+        id::Id,
+        test::image_hash,
         user::User,
     };
     use serde_test::Token;
@@ -118,13 +124,13 @@ mod tests {
             attachments: Vec::new(),
             author: User {
                 accent_color: None,
-                avatar: Some("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".to_owned()),
+                avatar: Some(image_hash::AVATAR),
                 banner: None,
                 bot: false,
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(3).expect("non zero"),
+                id: Id::new(3),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
@@ -133,14 +139,14 @@ mod tests {
                 system: None,
                 verified: None,
             },
-            channel_id: ChannelId::new(2).expect("non zero"),
+            channel_id: Id::new(2),
             components: Vec::new(),
             content: "ping".to_owned(),
             edited_timestamp: None,
             embeds: Vec::new(),
             flags: Some(MessageFlags::empty()),
-            guild_id: Some(GuildId::new(1).expect("non zero")),
-            id: MessageId::new(4).expect("non zero"),
+            guild_id: Some(Id::new(1)),
+            id: Id::new(4),
             interaction: None,
             kind: MessageType::Regular,
             member: Some(PartialMember {
@@ -164,7 +170,7 @@ mod tests {
             reference: None,
             sticker_items: vec![MessageSticker {
                 format_type: StickerFormatType::Png,
-                id: StickerId::new(1).expect("non zero"),
+                id: Id::new(1),
                 name: "sticker name".to_owned(),
             }],
             referenced_message: None,
@@ -193,7 +199,7 @@ mod tests {
                 Token::None,
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("banner"),
                 Token::None,
                 Token::Str("bot"),
@@ -201,13 +207,13 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("username"),
                 Token::Str("test"),
                 Token::StructEnd,
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("content"),
                 Token::Str("ping"),
@@ -221,10 +227,10 @@ mod tests {
                 Token::U64(0),
                 Token::Str("guild_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "MessageId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("4"),
                 Token::Str("type"),
                 Token::U8(0),
@@ -272,7 +278,7 @@ mod tests {
                 Token::Str("format_type"),
                 Token::U8(1),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "StickerId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("name"),
                 Token::Str("sticker name"),
@@ -302,23 +308,23 @@ mod tests {
                 party_id: None,
             }),
             application: Some(MessageApplication {
-                cover_image: Some("cover".to_owned()),
+                cover_image: Some(image_hash::COVER),
                 description: "a description".to_owned(),
-                icon: Some("an icon".to_owned()),
-                id: ApplicationId::new(1).expect("non zero"),
+                icon: Some(image_hash::ICON),
+                id: Id::new(1),
                 name: "application".to_owned(),
             }),
-            application_id: Some(ApplicationId::new(1).expect("non zero")),
+            application_id: Some(Id::new(1)),
             attachments: Vec::new(),
             author: User {
                 accent_color: None,
-                avatar: Some("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa".to_owned()),
+                avatar: Some(image_hash::AVATAR),
                 banner: None,
                 bot: false,
                 discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId::new(3).expect("non zero"),
+                id: Id::new(3),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
@@ -327,14 +333,14 @@ mod tests {
                 system: None,
                 verified: None,
             },
-            channel_id: ChannelId::new(2).expect("non zero"),
+            channel_id: Id::new(2),
             components: Vec::new(),
             content: "ping".to_owned(),
             edited_timestamp: Some(edited_timestamp),
             embeds: Vec::new(),
             flags: Some(MessageFlags::empty()),
-            guild_id: Some(GuildId::new(1).expect("non zero")),
-            id: MessageId::new(4).expect("non zero"),
+            guild_id: Some(Id::new(1)),
+            id: Id::new(4),
             interaction: None,
             kind: MessageType::Regular,
             member: Some(PartialMember {
@@ -350,8 +356,8 @@ mod tests {
                 user: None,
             }),
             mention_channels: vec![ChannelMention {
-                guild_id: GuildId::new(1).expect("non zero"),
-                id: ChannelId::new(2).expect("non zero"),
+                guild_id: Id::new(1),
+                id: Id::new(2),
                 kind: ChannelType::GuildText,
                 name: "channel".to_owned(),
             }],
@@ -367,21 +373,21 @@ mod tests {
                 me: true,
             }],
             reference: Some(MessageReference {
-                channel_id: Some(ChannelId::new(1).expect("non zero")),
+                channel_id: Some(Id::new(1)),
                 guild_id: None,
                 message_id: None,
                 fail_if_not_exists: None,
             }),
             sticker_items: vec![MessageSticker {
                 format_type: StickerFormatType::Png,
-                id: StickerId::new(1).expect("non zero"),
+                id: Id::new(1),
                 name: "sticker name".to_owned(),
             }],
             referenced_message: None,
             timestamp,
             thread: None,
             tts: false,
-            webhook_id: Some(WebhookId::new(1).expect("non zero")),
+            webhook_id: Some(Id::new(1)),
         };
 
         serde_test::assert_tokens(
@@ -408,25 +414,21 @@ mod tests {
                 },
                 Token::Str("cover_image"),
                 Token::Some,
-                Token::Str("cover"),
+                Token::Str(image_hash::COVER_INPUT),
                 Token::Str("description"),
                 Token::Str("a description"),
                 Token::Str("icon"),
                 Token::Some,
-                Token::Str("an icon"),
+                Token::Str(image_hash::ICON_INPUT),
                 Token::Str("id"),
-                Token::NewtypeStruct {
-                    name: "ApplicationId",
-                },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("name"),
                 Token::Str("application"),
                 Token::StructEnd,
                 Token::Str("application_id"),
                 Token::Some,
-                Token::NewtypeStruct {
-                    name: "ApplicationId",
-                },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("attachments"),
                 Token::Seq { len: Some(0) },
@@ -440,7 +442,7 @@ mod tests {
                 Token::None,
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("banner"),
                 Token::None,
                 Token::Str("bot"),
@@ -448,13 +450,13 @@ mod tests {
                 Token::Str("discriminator"),
                 Token::Str("0001"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("username"),
                 Token::Str("test"),
                 Token::StructEnd,
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("content"),
                 Token::Str("ping"),
@@ -469,10 +471,10 @@ mod tests {
                 Token::U64(0),
                 Token::Str("guild_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "MessageId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("4"),
                 Token::Str("type"),
                 Token::U8(0),
@@ -508,10 +510,10 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("type"),
                 Token::U8(0),
@@ -557,7 +559,7 @@ mod tests {
                 },
                 Token::Str("channel_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::StructEnd,
                 Token::Str("sticker_items"),
@@ -569,7 +571,7 @@ mod tests {
                 Token::Str("format_type"),
                 Token::U8(1),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "StickerId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("name"),
                 Token::Str("sticker name"),
@@ -581,7 +583,7 @@ mod tests {
                 Token::Bool(false),
                 Token::Str("webhook_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "WebhookId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::StructEnd,
             ],
