@@ -1,8 +1,11 @@
-use crate::{guild::Emoji, id::GuildId};
+use crate::{
+    guild::Emoji,
+    id::{marker::GuildMarker, Id},
+};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
 pub struct GuildEmojisUpdate {
     pub emojis: Vec<Emoji>,
-    pub guild_id: GuildId,
+    pub guild_id: Id<GuildMarker>,
 }
