@@ -59,13 +59,13 @@
     rust_2018_idioms,
     rustdoc::broken_intra_doc_links,
     unsafe_code,
-    unused,
-    warnings
+    unused
 )]
 #![allow(
     clippy::module_name_repetitions,
     clippy::must_use_candidate,
-    clippy::semicolon_if_nothing_returned
+    clippy::semicolon_if_nothing_returned,
+    clippy::used_underscore_binding
 )]
 
 pub mod application;
@@ -73,6 +73,7 @@ pub mod channel;
 pub mod datetime;
 pub mod gateway;
 pub mod guild;
+pub mod http;
 pub mod id;
 pub mod invite;
 pub mod oauth;
