@@ -38,7 +38,7 @@ mod tests {
     use crate::{
         channel::{
             permission_overwrite::{PermissionOverwrite, PermissionOverwriteType},
-            CategoryChannel, ChannelType, GuildChannel, TextChannel, VoiceChannel,
+            Channel, ChannelType,
         },
         datetime::{Timestamp, TimestampParseError},
         guild::{
@@ -80,20 +80,18 @@ mod tests {
         "afk_timeout": 300,
         "channels": [
             {{
-                "bitrate": 64000,
+                "bitrate": null,
                 "id": 1,
                 "name": "Text Channels",
                 "nsfw": false,
                 "parent_id": null,
                 "permission_overwrites": [],
                 "position": 0,
-                "rate_limit_per_user": 0,
                 "topic": null,
-                "type": 4,
-                "user_limit": 0
+                "type": 4
             }},
             {{
-                "bitrate": 64000,
+                "bitrate": null,
                 "id": 2,
                 "name": "general",
                 "nsfw": false,
@@ -115,21 +113,18 @@ mod tests {
                 "position": 0,
                 "rate_limit_per_user": 0,
                 "topic": null,
-                "type": 0,
-                "user_limit": 0
+                "type": 0
             }},
             {{
-                "bitrate": 64000,
+                "bitrate": null,
                 "id": 3,
                 "name": "Voice Channels",
                 "nsfw": false,
                 "parent_id": null,
                 "permission_overwrites": [],
                 "position": 0,
-                "rate_limit_per_user": 0,
                 "topic": null,
-                "type": 4,
-                "user_limit": 0
+                "type": 4
             }},
             {{
                 "bitrate": 64000,
@@ -139,7 +134,6 @@ mod tests {
                 "parent_id": 3,
                 "permission_overwrites": [],
                 "position": 0,
-                "rate_limit_per_user": 0,
                 "topic": null,
                 "type": 2,
                 "user_limit": 0
@@ -208,62 +202,137 @@ mod tests {
             serialized_source_guild: TemplateGuild {
                 afk_channel_id: None,
                 afk_timeout: 300,
-                channels: vec![
-                    GuildChannel::Category(CategoryChannel {
+                channels: Vec::from([
+                    Channel {
+                        application_id: None,
+                        bitrate: None,
+                        default_auto_archive_duration: None,
                         guild_id: None,
+                        icon: None,
                         id: Id::new(1),
+                        invitable: None,
                         kind: ChannelType::GuildCategory,
-                        name: "Text Channels".into(),
-                        permission_overwrites: vec![],
-                        position: 0,
-                    }),
-                    GuildChannel::Text(TextChannel {
+                        last_message_id: None,
+                        last_pin_timestamp: None,
+                        member: None,
+                        member_count: None,
+                        message_count: None,
+                        name: Some("Text Channels".into()),
+                        newly_created: None,
+                        nsfw: Some(false),
+                        owner_id: None,
+                        parent_id: None,
+                        permission_overwrites: Some(vec![]),
+                        position: Some(0),
+                        rate_limit_per_user: None,
+                        recipients: None,
+                        rtc_region: None,
+                        thread_metadata: None,
+                        topic: None,
+                        user_limit: None,
+                        video_quality_mode: None,
+                    },
+                    Channel {
+                        application_id: None,
+                        bitrate: None,
+                        default_auto_archive_duration: None,
                         guild_id: None,
+                        icon: None,
                         id: Id::new(2),
+                        invitable: None,
                         kind: ChannelType::GuildText,
                         last_message_id: None,
                         last_pin_timestamp: None,
-                        name: "general".into(),
-                        nsfw: false,
+                        member: None,
+                        member_count: None,
+                        message_count: None,
+                        name: Some("general".into()),
+                        newly_created: None,
+                        nsfw: Some(false),
+                        owner_id: None,
                         parent_id: Some(Id::new(1)),
-                        permission_overwrites: vec![
+                        permission_overwrites: Some(vec![
                             PermissionOverwrite {
                                 allow: Permissions::from_bits(0).unwrap(),
                                 deny: Permissions::from_bits(2048).unwrap(),
-                                kind: PermissionOverwriteType::Role(Id::new(1)),
+                                id: Id::new(1),
+                                kind: PermissionOverwriteType::Role,
                             },
                             PermissionOverwrite {
                                 allow: Permissions::from_bits(2048).unwrap(),
                                 deny: Permissions::from_bits(0).unwrap(),
-                                kind: PermissionOverwriteType::Role(Id::new(2)),
+                                id: Id::new(2),
+                                kind: PermissionOverwriteType::Role,
                             },
-                        ],
-                        position: 0,
+                        ]),
+                        position: Some(0),
                         rate_limit_per_user: Some(0),
-                        topic: None,
-                    }),
-                    GuildChannel::Category(CategoryChannel {
-                        guild_id: None,
-                        id: Id::new(3),
-                        kind: ChannelType::GuildCategory,
-                        name: "Voice Channels".into(),
-                        permission_overwrites: vec![],
-                        position: 0,
-                    }),
-                    GuildChannel::Voice(VoiceChannel {
-                        bitrate: 64000,
-                        guild_id: None,
-                        id: Id::new(4),
-                        kind: ChannelType::GuildVoice,
-                        name: "General".into(),
-                        parent_id: Some(Id::new(3)),
-                        permission_overwrites: vec![],
+                        recipients: None,
                         rtc_region: None,
-                        position: 0,
+                        thread_metadata: None,
+                        topic: None,
+                        user_limit: None,
+                        video_quality_mode: None,
+                    },
+                    Channel {
+                        application_id: None,
+                        bitrate: None,
+                        default_auto_archive_duration: None,
+                        guild_id: None,
+                        icon: None,
+                        id: Id::new(3),
+                        invitable: None,
+                        kind: ChannelType::GuildCategory,
+                        last_message_id: None,
+                        last_pin_timestamp: None,
+                        member: None,
+                        member_count: None,
+                        message_count: None,
+                        name: Some("Voice Channels".into()),
+                        newly_created: None,
+                        nsfw: Some(false),
+                        owner_id: None,
+                        parent_id: None,
+                        permission_overwrites: Some(vec![]),
+                        position: Some(0),
+                        rate_limit_per_user: None,
+                        recipients: None,
+                        rtc_region: None,
+                        thread_metadata: None,
+                        topic: None,
+                        user_limit: None,
+                        video_quality_mode: None,
+                    },
+                    Channel {
+                        application_id: None,
+                        bitrate: Some(64000),
+                        default_auto_archive_duration: None,
+                        guild_id: None,
+                        icon: None,
+                        id: Id::new(4),
+                        invitable: None,
+                        kind: ChannelType::GuildVoice,
+                        last_message_id: None,
+                        last_pin_timestamp: None,
+                        member: None,
+                        member_count: None,
+                        message_count: None,
+                        name: Some("General".into()),
+                        newly_created: None,
+                        nsfw: Some(false),
+                        owner_id: None,
+                        parent_id: Some(Id::new(3)),
+                        permission_overwrites: Some(vec![]),
+                        position: Some(0),
+                        rate_limit_per_user: None,
+                        recipients: None,
+                        rtc_region: None,
+                        thread_metadata: None,
+                        topic: None,
                         user_limit: Some(0),
                         video_quality_mode: None,
-                    }),
-                ],
+                    },
+                ]),
                 default_message_notifications: DefaultMessageNotificationLevel::All,
                 description: None,
                 explicit_content_filter: ExplicitContentFilter::None,
@@ -388,8 +457,8 @@ mod tests {
                 Token::Str("channels"),
                 Token::Seq { len: Some(4) },
                 Token::Struct {
-                    name: "CategoryChannel",
-                    len: 5,
+                    name: "Channel",
+                    len: 6,
                 },
                 Token::Str("id"),
                 Token::NewtypeStruct { name: "Id" },
@@ -397,15 +466,21 @@ mod tests {
                 Token::Str("type"),
                 Token::U8(4),
                 Token::Str("name"),
+                Token::Some,
                 Token::Str("Text Channels"),
+                Token::Str("nsfw"),
+                Token::Some,
+                Token::Bool(false),
                 Token::Str("permission_overwrites"),
+                Token::Some,
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
                 Token::Str("position"),
+                Token::Some,
                 Token::I64(0),
                 Token::StructEnd,
                 Token::Struct {
-                    name: "TextChannel",
+                    name: "Channel",
                     len: 8,
                 },
                 Token::Str("id"),
@@ -414,17 +489,20 @@ mod tests {
                 Token::Str("type"),
                 Token::U8(0),
                 Token::Str("name"),
+                Token::Some,
                 Token::Str("general"),
                 Token::Str("nsfw"),
+                Token::Some,
                 Token::Bool(false),
                 Token::Str("parent_id"),
                 Token::Some,
                 Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("permission_overwrites"),
+                Token::Some,
                 Token::Seq { len: Some(2) },
                 Token::Struct {
-                    name: "PermissionOverwriteData",
+                    name: "PermissionOverwrite",
                     len: 4,
                 },
                 Token::Str("allow"),
@@ -432,12 +510,13 @@ mod tests {
                 Token::Str("deny"),
                 Token::Str("2048"),
                 Token::Str("id"),
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("type"),
                 Token::U8(0),
                 Token::StructEnd,
                 Token::Struct {
-                    name: "PermissionOverwriteData",
+                    name: "PermissionOverwrite",
                     len: 4,
                 },
                 Token::Str("allow"),
@@ -445,20 +524,22 @@ mod tests {
                 Token::Str("deny"),
                 Token::Str("0"),
                 Token::Str("id"),
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("type"),
                 Token::U8(0),
                 Token::StructEnd,
                 Token::SeqEnd,
                 Token::Str("position"),
+                Token::Some,
                 Token::I64(0),
                 Token::Str("rate_limit_per_user"),
                 Token::Some,
                 Token::U64(0),
                 Token::StructEnd,
                 Token::Struct {
-                    name: "CategoryChannel",
-                    len: 5,
+                    name: "Channel",
+                    len: 6,
                 },
                 Token::Str("id"),
                 Token::NewtypeStruct { name: "Id" },
@@ -466,18 +547,25 @@ mod tests {
                 Token::Str("type"),
                 Token::U8(4),
                 Token::Str("name"),
+                Token::Some,
                 Token::Str("Voice Channels"),
+                Token::Str("nsfw"),
+                Token::Some,
+                Token::Bool(false),
                 Token::Str("permission_overwrites"),
+                Token::Some,
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
                 Token::Str("position"),
+                Token::Some,
                 Token::I64(0),
                 Token::StructEnd,
                 Token::Struct {
-                    name: "VoiceChannel",
-                    len: 8,
+                    name: "Channel",
+                    len: 9,
                 },
                 Token::Str("bitrate"),
+                Token::Some,
                 Token::U64(64000),
                 Token::Str("id"),
                 Token::NewtypeStruct { name: "Id" },
@@ -485,15 +573,21 @@ mod tests {
                 Token::Str("type"),
                 Token::U8(2),
                 Token::Str("name"),
+                Token::Some,
                 Token::Str("General"),
+                Token::Str("nsfw"),
+                Token::Some,
+                Token::Bool(false),
                 Token::Str("parent_id"),
                 Token::Some,
                 Token::NewtypeStruct { name: "Id" },
                 Token::Str("3"),
                 Token::Str("permission_overwrites"),
+                Token::Some,
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
                 Token::Str("position"),
+                Token::Some,
                 Token::I64(0),
                 Token::Str("user_limit"),
                 Token::Some,
